@@ -1,14 +1,18 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+package Mail::Message;{
+our $VERSION = '3.017';
+}
+
 
 use strict;
-
-package Mail::Message;
-use vars '$VERSION';
-$VERSION = '3.003';
-
+use warnings;
 
 use IO::Lines;
 
